@@ -2,13 +2,13 @@ use strict;
 use 5.006;
 
 package HTML::Restrict;
-$HTML::Restrict::VERSION = '2.2.2';
+$HTML::Restrict::VERSION = '2.2.3';
 use Carp qw( croak );
 use Data::Dump qw( dump );
 use HTML::Parser;
 use HTML::Entities qw( encode_entities );
-use Types::Standard qw[ Bool HashRef ArrayRef CodeRef ];
-use List::MoreUtils qw( any none );
+use Types::Standard 1.000001 qw[ Bool HashRef ArrayRef CodeRef ];
+use List::Util 1.33 qw( any none );
 use Scalar::Util qw( reftype weaken );
 use Sub::Quote 'quote_sub';
 use URI;
@@ -333,7 +333,7 @@ HTML::Restrict - Strip unwanted HTML tags and attributes
 
 =head1 VERSION
 
-version 2.2.2
+version 2.2.3
 
 =head1 SYNOPSIS
 
@@ -602,6 +602,14 @@ This is the method which does the real work.  It parses your data, removes any
 tags and attributes which are not specifically allowed and returns the
 resulting text.  Requires and returns a SCALAR.
 
+=head2 get_rules
+
+Accessor which returns a hash ref of the current rule set.
+
+=head2 get_uri_schemes
+
+Accessor which returns an array ref of the current valid uri schemes.
+
 =head1 CAVEATS
 
 Please note that all tag and attribute names passed via the rules param must be
